==> mediawiki-1.12.4.tbz: www/mediawiki/languages/messages/MessagesAv.php <==
<?php
/** Avaric (Авар)
 *
 * @ingroup Language
 * @file
 *
 * @author MONARCH79
 * @author Phoebe
 */

$fallback = 'ru';

$messages = array(
# Dates
'sunday'    => 'ГьатIан',
'monday'    => 'Итни',
'tuesday'   => 'Талат',
'wednesday' => 'АрбагI',
'thursday'  => 'Хамиз',
'friday'    => 'Рузман',
'saturday'  => 'Шаммат',

'mytalk' => 'Дур бахlс',
'and'    => 'ва',

'errorpagetitle' => 'Гъалатl',
'help'           => 'Кумек',
'history'        => 'Хиса-басазул тарих',
'edit'           => 'Хисизабе',
'talkpage'       => 'Гьумералда тlасан бахlс',
'talk'           => 'Бахlс',
'toolbox'        => 'Алатал',
'userpage'       => 'ГIахьалчиясул гьумер',
'otherlanguages' => 'Цойги мацIазда',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents' => 'Жакъасел лъугьа-бахъинал',
'mainpage'      => 'БетIераб гьумер',
'portal'        => 'Майдан',
'portal-url'    => 'Project:Майдан',
'sitesupport'   => 'Садакъа',

'editsection' => 'хисизабизе',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-help' => 'Кумек',

# General errors
'error'         => 'Гъалатl',
'internalerror' => 'Жанисеб гъалатl',
'viewsource'    => 'Код бихьи',

# Login and logout pages
'loginpagetitle' => 'Цlар бице',
'userlogin'      => 'ЦIар бице',
'userlogout'     => 'Къватlиве лъугьине',

# Edit pages
'savearticle' => 'Хъвай-хъвай цIунизе',

# Preferences page
'preferences'        => 'Рекъезаби',
'math_unknown_error' => 'Лъалареб гъалатl',
'localtime'          => 'Бакlалъул заман',

# User rights
'userrights-user-editname' => 'ГIахьалчиясул цIар хъвай:',

# Recent changes
'recentchanges'   => 'ЦIиял хиса-басал',
'rcshowhideminor' => '$1 гIиси-микъинал хиса-басал',
'rcshowhidebots'  => '$1 бот',
'rcshowhideliu'   => '$1 цIар рагьарал гIахьалчагIи',
'rcshowhideanons' => '$1 цIаргьечI',
'rcshowhidemine'  => '$1 дир хиса-басал',
'diff'            => 'батIалъи',
'hide'            => 'Бахчизе',
'show'            => 'Бихьизабизе',
'minoreditletter' => 'гI.-м.',
'newpageletter'   => 'ЦI',

# Upload
'uploadnologin' => 'Дуца цIар бицун гьечIо',

# Random page
'randompage' => 'Цебе ккараб гьумер',

# Miscellaneous special pages
'shortpages'   => 'Къокъал макъалаби',
'longpages'    => 'Кlудиял гьумерал',
'listusers'    => 'Гlахьалчагlазул сияхl',
'specialpages' => 'Хассал гьумерал',

# Special:Log
'specialloguserlabel' => 'ГIахьалчи:',

# Special:Allpages
'allarticles' => 'Киналго макъалаби',

# Watchlist
'watchlist' => 'Дур халгьабиялъул сияхl',
'watch'     => 'хал гьабизе',

# Contributions
'contributions' => 'ГIахьалчиясул хIалтIи',
'mycontris'     => 'Дур гlахьаллъи',

# Move page
'movepage'    => 'Гьумералъул цlар хисизе',
'movearticle' => 'Гьумералъул цIар хисизе',
'movepagebtn' => 'Гьумералъул цlар хисизе',

);

==> mediawiki-1.14.1.tbz: www/mediawiki/languages/messages/MessagesAv.php <==
<?php
/** Avaric (Авар)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author MF-Warburg
 * @author MONARCH79
 * @author Phoebe
 */

$fallback = 'ru';

$messages = array(
# Dates
'sunday'    => 'ГьатIан',
'monday'    => 'Итни',
'tuesday'   => 'Талат',
'wednesday' => 'АрбагI',
'thursday'  => 'Хамиз',
'friday'    => 'Рузман',
'saturday'  => 'Шаммат',

'mytalk' => 'Дур бахlс',
'and'    => '&#32;ва',

'errorpagetitle' => 'Гъалатl',
'help'           => 'Кумек',
'history'        => 'Хиса-басазул тарих',
'edit'           => 'Хисизабе',
'talkpage'       => 'Гьумералда тlасан бахlс',
'talk'           => 'Бахlс',
'toolbox'        => 'Алатал',
'userpage'       => 'ГIахьалчиясул гьумер',
'otherlanguages' => 'Цойги мацIазда',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Жакъасел лъугьа-бахъинал',
'mainpage'             => 'БетIераб гьумер',
'mainpage-description' => 'БетIераб гьумер',
'portal'               => 'Майдан',
'portal-url'           => 'Project:Майдан',

'editsection' => 'хисизабизе',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-help' => 'Кумек',

# General errors
'error'         => 'Гъалатl',
'internalerror' => 'Жанисеб гъалатl',
'viewsource'    => 'Код бихьи',

# Login and logout pages
'loginpagetitle' => 'Цlар бице',
'userlogin'      => 'ЦIар бице',
'userlogout'     => 'Къватlиве лъугьине',

# Edit pages
'savearticle' => 'Хъвай-хъвай цIунизе',

# Preferences page
'preferences'        => 'Рекъезаби',
'math_unknown_error' => 'Лъалареб гъалатl',
'localtime'          => 'Бакlалъул заман',

# User rights
'userrights-user-editname' => 'ГIахьалчиясул цIар хъвай:',

# Recent changes
'recentchanges'   => 'ЦIиял хиса-басал',
'rcshowhideminor' => '$1 гIиси-микъинал хиса-басал',
'rcshowhidebots'  => '$1 бот',
'rcshowhideliu'   => '$1 цIар рагьарал гIахьалчагIи',
'rcshowhideanons' => '$1 цIаргьечI',
'rcshowhidemine'  => '$1 дир хиса-басал',
'diff'            => 'батIалъи',
'hide'            => 'Бахчизе',
'show'            => 'Бихьизабизе',
'minoreditletter' => 'гI.-м.',
'newpageletter'   => 'ЦI',

# Upload
'uploadnologin' => 'Дуца цIар бицун гьечIо',

# Random page
'randompage' => 'Цебе ккараб гьумер',

# Miscellaneous special pages
'shortpages' => 'Къокъал макъалаби',
'longpages'  => 'Кlудиял гьумерал',
'listusers'  => 'Гlахьалчагlазул сияхl',

# Special:Log
'specialloguserlabel' => 'ГIахьалчи:',

# Special:AllPages
'allarticles' => 'Киналго макъалаби',

# Special:Log/newusers
'newuserlog-create-entry' => 'ЦIияв гIахьалчи',

# Watchlist
'watchlist' => 'Дур халгьабиялъул сияхl',
'watch'     => 'хал гьабизе',

# Contributions
'contributions' => 'ГIахьалчиясул хIалтIи',
'mycontris'     => 'Дур гlахьаллъи',

# Move page
'move-page-legend' => 'Гьумералъул цlар хисизе',
'movearticle'      => 'Гьумералъул цIар хисизе',
'movepagebtn'      => 'Гьумералъул цlар хисизе',

# Special:SpecialPages
'specialpages' => 'Хассал гьумерал',

);
